@@ -698,6 +698,10 @@ static inline bubblemon_color_t bubblemon_interpolateColor(const bubblemon_color
   int a, r, g, b;
   bubblemon_color_t returnme;
 
+  if (amount == 0) {
+     return c1;
+  }
+
   assert(amount >= 0 && amount < 256);
 
   r = ((((int)c1.components.r) * (255 - amount)) +
@@ -730,8 +734,10 @@ static inline bubblemon_color_t bubblemon_interpolateColor(const bubblemon_color
   returnme.components.b = b;
   returnme.components.a = a;
 
+  /*
   assert((amount != 0)   || (returnme.value == c1.value));
   assert((amount != 255) || (returnme.value == c2.value));
+  */
 
   return returnme;
 }
@@ -1096,10 +1102,13 @@ static void bubblemon_bubbleArrayToPixmap(bubblemon_t *bubblemon,
   } else {
     // Draw on top of the current pic
     for (i = 0; i < w * h; i++) {
-      bubblemon_color_t myColor = colors[*airOrWater++];
-      *pixel = bubblemon_interpolateColor(*pixel,
-					  myColor,
-					  myColor.components.a);
+      bubblemon_color_t currentColor = *pixel;
+      bubblemon_color_t newColor = colors[*airOrWater++];
+      if (newColor.value != currentColor.value) {
+        *pixel = bubblemon_interpolateColor(currentColor,
+                                            newColor,
+                                            newColor.components.a);
+      }
       pixel++;
     }
   }
